.TH abinv 1 "April 1993" "Scilab Group" "Scilab Function"
.so ../sci.an 
.SH NAME
abinv -  AB invariant subspace
.SH CALLING SEQUENCE
.nf
[X,dims,F,U,k,Z]=abinv(Sl,alfa,beta)
.fi
.SH PARAMETERS
.TP 10
sl
: \fVsyslin\fR list containing the matrices \fV[A,B,C,D]\fR.
.TP
alfa 
: real number or vector (possibly complex, location of closed loop poles)
.TP
beta
: real number or vector (possibly complex, location of closed loop poles)
.TP
X
: orthogonal matrix of size nx (dim of state space).
.TP
dims
:
integer row vector \fVdims=[dimR,dimVg,dimV,noc,nos]\fR with \fVdimR<=dimVg<=dimV<=noc<=nos\fR
.TP
F
: real matrix (state feedback)
.TP
k
: integer (normal rank of \fVSl\fR)
.TP
Z
: non-singular linear system (\fVsyslin\fR list)
.SH DESCRIPTION
Output nulling subspace (maximal unobservable subspace) for
\fVSl\fR = linear system defined by a syslin list containing
the matrices [A,B,C,D] of \fVSl\fR.
The vector \fVdims=[dimR,dimVg,dimV,noc,nos]\fR gives the dimensions
of subspaces defined as columns od \fVX\fR.
The \fVdimV\fR first columns of \fVX\fR i.e \fVV=X(:,1:dimV)\fR, 
span the AB-invariant subspace of \fVSl\fR i.e the unobservable subspace of 
\fV(A+B*F,C+D*F)\fR. (\fVdimV=nx\fR  iff C^(-1)(D)=X).
.LP
The \fVdimR\fR first columns of \fVX\fR i.e. \fVR=X(:,1:dimR)\fR spans  
the controllable part of \fVSl\fR in \fVV\fR, \fV(dimR<=dimV)\fR. (\fVdimR=0\fR
for a left invertible system). \fVR\fR is the maximal controllability
subspace of \fVSl\fR in \fVkernel(C)\fR.
.LP
The \fVdimVg\fR first columns of \fVX\fR spans 
\fVVg\fR=maximal AB-stabilizable subspace of \fVSl\fR. \fV(dimR<=dimVg<=dimV)\fR.
.LP
\fVF\fR is a decoupling feedback: for \fVX=[V,X2] (X2=X(:,dimV+1:nx))\fR one has 
\fVX2'*(A+B*F)*V=0 and (C+D*F)*V=0\fR.
.LP
The zeros od \fVSl\fR are given by : \fVX0=X(:,dimR+1:dimV); spec(X0'*(A+B*F)*X0)\fR
i.e. there are \fVdimV-dimR\fR closed-loop fixed modes.
.LP
If the optional parameter \fValfa\fR is given as input, 
the \fVdimR\fR controllable modes of \fV(A+BF)\fR in \fVV\fR 
are set to \fValfa\fR (or to \fV[alfa(1), alfa(2), ...]\fR.
(\fValfa\fR can be a vector (real or complex pairs) or a (real) number).
Default value \fValfa=-1\fR.
.LP
If the optional real parameter \fVbeta\fR is given as input, 
the \fVnoc-dimV\fR controllable modes of \fV(A+BF)\fR "outside" \fVV\fR 
are set to \fVbeta\fR (or \fV[beta(1),beta(2),...]\fR). Default value \fVbeta=-1\fR.
.LP
In the \fVX,U\fR bases, the matrices 
\fV[X'*(A+B*F)*X,X'*B*U;(C+D*F)*X,D*U]\fR 
are displayed as follows:
.nf

[A11,*,*,*,*,*]  [B11 * ]
[0,A22,*,*,*,*]  [0   * ]
[0,0,A33,*,*,*]  [0   * ]
[0,0,0,A44,*,*]  [0  B42]
[0,0,0,0,A55,*]  [0   0 ]
[0,0,0,0,0,A66]  [0   0 ]

[0,0,0,*,*,*]    [0  D2]
.fi
where the X-partitioning is defined by \fVdims\fR and 
the U-partitioning is defined by \fVk\fR.
.LP
\fVA11\fR is \fV(dimR x dimR)\fR and has its eigenvalues set to \fValfa(i)'s\fR.
The pair \fV(A11,B11)\fR is controllable and \fVB11\fR has \fVnu-k\fR columns. 
\fVA22\fR is a stable \fV(dimVg-dimR x dimVg-dimR)\fR matrix.
\fVA33\fR is an unstable \fV(dimV-dimVg x dimV-dimVg)\fR matrix (see \fVst_ility\fR).
.LP
\fVA44\fR is \fV(noc-dimV x noc-dimV)\fR and has its eigenvalues set to \fVbeta(i)'s\fR.
The pair \fV(A44,B42)\fR is controllable. 
\fVA55\fR is a stable \fV(nos-noc x nos-noc)\fR matrix.
\fVA66\fR is an unstable \fV(nx-nos x nx-nos)\fR matrix (see \fVst_ility\fR).
.LP
\fVZ\fR is a column compression of \fVSl\fR and \fVk\fR is
the normal rank of \fVSl\fR i.e \fVSl*Z\fR is a column-compressed linear
system. \fVk\fR is the column dimensions of \fVB42,B52,B62\fR and \fVD2\fR.
\fV[B42;B52;B62;D2]\fR is full column rank and has rank \fVk\fR.
.LP
This function can be used for the (exact) disturbance decoupling problem.
.nf
DDPS:
   Find u=Fx+Rd which reject Q*d and stabilizes the plant:

    xdot=Ax+Bu+Qd
    y=Cx+Du
DDPS has a solution iff Im(Q) is included in Vg + Im(B). 
Let G=(X(:,dimVg+1:nx))'= left annihilator of Vg i.e. G*Vg=0;
B2=G*B; Q2=G*Q; DDPS solvable iff B2(:,1:k)*R1 + Q2 =0 has a solution.
R=[R1;*] is the solution  (with F=output of abinv).
Im(Q2) is in Im(B2) means row-compression of B2=>row-compression of Q2
Then C*[(sI-A-B*F)^(-1)+D]*(Q+B*R) =0   (<=>G*(Q+B*R)=0)
.fi
.SH EXAMPLE
.nf
nu=3;ny=4;nx=7;
nrt=2;ngt=3;ng0=3;nvt=5;rk=2;
flag=list('on',nrt,ngt,ng0,nvt,rk);
Sl=ssrand(ny,nu,nx,flag);alfa=-1;beta=-2;
[X,dims,F,U,k,Z]=abinv(Sl,alfa,beta);
[A,B,C,D]=abcd(Sl);dimV=dims(3);dimR=dims(1);
V=X(:,1:dimV);X2=X(:,dimV+1:nx);
X2'*(A+B*F)*V
(C+D*F)*V
X0=X(:,dimR+1:dimV); spec(X0'*(A+B*F)*X0)
trzeros(Sl)
spec(A+B*F)   //nr=2 evals at -1 and noc-dimV=2 evals at -2.
clean(ss2tf(Sl*Z))
A=diag(1:6);A(2,2)=-7;A(5,5)=-9;B=[1,2;0,3;0,4;0,5;0,0;0,0];C=[zeros(3,3),eye(3,3)];
sl=syslin('c',A,B,C);sl=ss2ss(sl,rand(6,6));
[X,dims,F,U,k,Z]=abinv(sl,alfa,beta);
[A,B,C,D]=abcd(sl);clean(X'*(A+B*F)*X)
clean(X'*B*U)

.fi
.SH AUTHOR
F.D.
.SH SEE ALSO
cainv, st_ility, ssrand, ss2ss

